import { Modal, ModalService } from '@zeedhi/common';

import { SocketEvent } from '@/socket/socket-event';
import {
  Config,
  IDictionary,
  IEventParam,
} from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { io, Socket } from 'socket.io-client';

export class SatController {
  public socket?: Socket;

  public title: any;

  private fullscreenModal!: Modal;

  public async createFullscreenModal() {
    this.fullscreenModal = await ModalService.createFromJson('sat', true);
  }

  public destroyFullscreenModal() {
    this.fullscreenModal?.destroy();
  }

  public openFullscreenModal(row:any) {
    if (row.row.sat !== true) {
      this.fullscreenModal.show();
    }
    this.title = 'Monitoramento de SAT da ';
    this.title += row.row.name;
    this.title += ' - ';
    this.title += row.row.id;
  }

  public closeFullscreenModal() {
    this.fullscreenModal.hide();
  }

  /** Status do Sat */
  public getConditionalStyle({ row }: IDictionary<any>) {
    if (row.STATUS === 'true') {
      return 'green';
    }
    return 'red';
  }

  /** Status do Sat */
  public getConditionalMessageSat({ row }: IDictionary<any>) {
    if (
      (row.STATUS === '') && (row.mensagem === '')
    ) {
      return 'SAT indisponível.';
    }
    return row.mensagem;
  }

  /**
   * Método executado quando o grid é criado
   */
  public gridMounted({ component }: IEventParam<TekGrid>) {
    // inicializa o socket
    this.socket = io(Config.endPoint, {
      transports: ['websocket', 'polling'],
    });

    this.socket.off(SocketEvent.CONNECTION)
      .emit('sat', {
        slave: false,
      });

    this.socket.off(SocketEvent.CONNECTION)
      .on('sat', async (branc: IDictionary) => {
        await component.datasource.updateData(branc.message.vendas);
        await component.datasource.get();
      });
  }

  /**
   * Método executado logo antes do grid ser destruído
   */
  public gridBeforeDestroy() {

  }
}
