import { Modal, ModalService } from '@zeedhi/common';

import { SocketEvent } from '@/socket/socket-event';
import {
  Config,
  IDictionary,
  IEventParam,
} from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { io, Socket } from 'socket.io-client';

export class SefazController {
  public socket?: Socket;

  public filialId: any;

  public title: any;

  private fullscreenModal!: Modal;

  public async createFullscreenModal() {
    this.fullscreenModal = await ModalService.createFromJson('sefaz', true);
  }

  public destroyFullscreenModal() {
    this.fullscreenModal?.destroy();
  }

  public openFullscreenModal(row:any) {
    // console.warn(row);
    this.filialId = row.row;
    this.title = 'Monitoramento da Sefaz ';
    if (row.row.sat !== true) {
      this.fullscreenModal.show();
    }
    this.fullscreenModal.show();
  }

  public closeFullscreenModal() {
    this.fullscreenModal.hide();
  }

  /** Status do Normal */
  public getConditionalStyleNormal({ row }: IDictionary<any>) {
    if (row.idnormal === 'CINZA') {
      return 'Gray';
    }
    return 'green';
  }

  /** Status do Normal */
  public getConditionalNormal({ row }: IDictionary<any>) {
    let message = '';
    if (row.idnormal === 'CINZA') {
      message = 'falta Serviço ou falha de conexão.';
    } else if (row.idnormal === 'VERDE') {
      message = 'Sistema operante.';
    } else {
      message = row.message;
    }
    return message;
  }

  /** Status do Vendas */
  public getConditionalStyleScan({ row }: IDictionary<any>) {
    if (row.idscan === 'CINZA') {
      return 'green';
    }
    return 'red';
  }

  public getConditionalScan({ row }: IDictionary<any>) {
    if (row.idscan === 'CINZA') {
      return 'green';
    }
    return 'red';
  }

  /** Status do Vendas */
  public getConditionalStyleSvc({ row }: IDictionary<any>) {
    if (row.idsvc === 'CINZA') {
      return 'green';
    }
    return 'red';
  }

  public getConditionalSvc({ row }: IDictionary<any>) {
    if (row.idsvc === 'CINZA') {
      return 'green';
    }
    return 'red';
  }

  /**
   * Método executado quando o grid é criado
   */
  public gridMounted({ component }: IEventParam<TekGrid>) {
    // inicializa o socket
    this.socket = io(Config.endPoint, {
      transports: ['websocket', 'polling'],
    });

    this.socket.off(SocketEvent.CONNECTION)
      .emit('sefaz', {
        slave: false,
      });

    this.socket.off(SocketEvent.CONNECTION)
      .on('sefaz', async (branc: IDictionary) => {
        await component.datasource.updateData(branc.message.data);
        await component.datasource.get();
      });
  }

  /**
   * Método executado logo antes do grid ser destruído
   */
  public gridBeforeDestroy() {

  }
}
